==> FHLBBS-4.2.tgz: util/chkactive.c <==
#include <sys/types.h>
#include <dirent.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/stat.h>
#include <time.h>
#include <fcntl.h>

#define HOMEDIR "/home/bbs/active"
#define TIMEOUT 30*60
#define WFN_USIES "/home/bbs/wusies"	/* WBBS log */

char *
Cdate(clock)
  time_t *clock;
{
  static char foo[22];
  struct tm *mytm = localtime(clock);

  strftime(foo, 22, "%D %T %a", mytm);
  return (foo);
}
main()
{
 char genbuf[256],buf[128];
 DIR *dirpt;
 struct dirent *filept;
 struct stat st;
 FILE *fin,*fpftp;
 time_t now,start;
 
 if ((dirpt=opendir(HOMEDIR))==NULL) /**** open dir error ***/
 {
	sprintf(genbuf,"Error in open %s",HOMEDIR);
       exit(1);
 }
 /**** Read each entry of all file in this directory ****/
 while((filept=readdir(dirpt))!=NULL) /*** if entries in this directory **/
 { 
   /** puts(filept->d_name); **/
   /**** find xxx.inf file *****/
   if (strchr(filept->d_name,'.')) continue;
   sprintf(genbuf,HOMEDIR "/%s",filept->d_name);
   if( stat(genbuf, &st ) < 0 ) continue;
   now=time(0);
   if ((now-st.st_mtime)>TIMEOUT) /*** time out **/
   {
     fin=fopen(genbuf,"r");
     if(fgets(genbuf, 64, fin) != NULL)
     {
        start=atol(genbuf);
     } 
     else start =0;
     fclose(fin);
     if (fin = fopen(WFN_USIES, "a+"))
     {
        sprintf(genbuf, "Stay: %d (%s)",
        (now - start) / 60, filept->d_name);
        fprintf(fin, "%s %s %-12s %s\n",
      Cdate(&now), "AXXED", filept->d_name, genbuf);
     }
     fclose(fin);
     sprintf(genbuf,HOMEDIR "/%s",filept->d_name);
     remove(genbuf);
   }     
 } /*** open directory ***/
 closedir(dirpt);
}

==> FHLBBS-5.3.tgz: util/chkactive.c <==
#include <sys/types.h>
#include <dirent.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <sys/stat.h>
#include <time.h>
#include <fcntl.h>

#define HOMEDIR "/home/bbs/active"
#define TIMEOUT 30*60
#define WFN_USIES "/home/bbs/wusies"	/* WBBS log */

char *
Cdate(clock)
  time_t *clock;
{
  static char foo[24];
  struct tm *mytm = localtime(clock);

  strftime(foo, 24, "%m/%d/%Y %T %a", mytm);
  return (foo);
}
main()
{
 char genbuf[256],buf[128];
 DIR *dirpt;
 struct dirent *filept;
 struct stat st;
 FILE *fin,*fpftp;
 time_t now,start;
 
 if ((dirpt=opendir(HOMEDIR))==NULL) /**** open dir error ***/
 {
	sprintf(genbuf,"Error in open %s",HOMEDIR);
       exit(1);
 }
 /**** Read each entry of all file in this directory ****/
 while((filept=readdir(dirpt))!=NULL) /*** if entries in this directory **/
 { 
   /** puts(filept->d_name); **/
   /**** find xxx.inf file *****/
   if (strchr(filept->d_name,'.')) continue;
   sprintf(genbuf,HOMEDIR "/%s",filept->d_name);
   if( stat(genbuf, &st ) < 0 ) continue;
   now=time(0);
   if ((now-st.st_mtime)>TIMEOUT) /*** time out **/
   {
     fin=fopen(genbuf,"r");
     if(fgets(genbuf, 64, fin) != NULL)
     {
        start=atol(genbuf);
     } 
     else start =0;
     fclose(fin);
     if (fin = fopen(WFN_USIES, "a+"))
     {
        sprintf(genbuf, "Stay: %d (%s)",
        (now - start) / 60, filept->d_name);
        fprintf(fin, "%s %s %-12s %s\n",
      Cdate(&now), "AXXED", filept->d_name, genbuf);
     }
     fclose(fin);
     sprintf(genbuf,HOMEDIR "/%s",filept->d_name);
     remove(genbuf);
   }     
 } /*** open directory ***/
 closedir(dirpt);
}
